@@ -8,13 +8,13 @@
 #' @keywords univar manip arith
 #' @export
 #' @examples
-#' 
-#' sortDF(USArrests[USArrests$Murder>11,], "Assault")
+#' sortDF(USArrests[USArrests$Murder>11,], Assault)
+#' sortDF(USArrests[USArrests$Murder>11,], "Assault") # safer within functions
 #' sortDF(USArrests[USArrests$Murder>11,], 3)
 #' 
 #' @param df Data.frame to be sorted
-#' @param col Column (index or (un)qouted name) to be sorted by
-#' @param decreasing Logical: should highest value be on top? 
+#' @param col Column (index or (un)quoted name) to be sorted by
+#' @param decreasing Logical: should highest value be on top?
 #'                   DEFAULT: TRUE (unlike \code{\link{order}}!)
 #' @param \dots Further arguments passed to \code{\link{order}}, like eg \code{na.last or method}
 #' 
@@ -25,6 +25,6 @@ decreasing=TRUE,
 ...
 )
 {
-values <- getColumn(col,df)
+values <- getColumn(substitute(col),df)
 df[order(values, decreasing=decreasing, ...),]
 }
